@@ -1,4 +1,5 @@
 #!/usr/bin/perl
+use warnings;
 use strict;
 $|++;
 
@@ -88,8 +89,8 @@ my $file = 'data/cpan100.csv';
 if(my $fh = IO::File->new($file,'r')) {
     while(<$fh>) {
         s/\s+$//;
-        next    if(!$_ or $_ =~ /^#/);
-        my ($pause,$cnt,$name) = split(',');
+        next    if(not $_ or $_ =~ /^#/);
+        my ($pause,$cnt,$name) = split(/,/);
         next unless($pause);
 
         $inx++;
@@ -113,8 +114,8 @@ while(<$fh>) {
         $tvars{WHEN} = $1;
     }
 
-    next    if(!$_ or $_ =~ /^#/);
-    my ($pause,$cnt,$name) = split(',');
+    next    if(not $_ or $_ =~ /^#/);
+    my ($pause,$cnt,$name) = split(/,/);
     next unless($pause);
 
     $inx++;
@@ -209,7 +210,7 @@ $changes->releases( @releases );
 
 $fh = IO::File->new($file,'w+') or die "Cannot open file [$file]: $!\n";
 my $content = $changes->serialize;
-my @content = split("\n",$content);
+my @content = split(/\n/,$content);
 $content = '';
 for my $line (@content) {
     $line =~ s/^([\d.]+)\s+(.*?)$/$1    $2/;
